@@ -587,7 +587,7 @@ void default_keybindings()
    add_binding(XK_KP_Add, XCF_Superscript);
    add_binding(XK_KP_Subtract, XCF_Subscript);
    add_binding(XK_KP_Enter, XCF_Normalscript);
-   add_binding(ALT | XK_f, XCF_Nextfont);
+   add_vbinding(ALT | XK_f, XCF_Font, 1000);
    add_binding(ALT | XK_b, XCF_Boldfont);
    add_binding(ALT | XK_i, XCF_Italicfont);
    add_binding(ALT | XK_n, XCF_Normalfont);
